(function ($, Drupal) {
  Drupal.behaviors.google_analytics_search_api_autocomplete = {
    attach: function (context, settings) {
      // Follow settings of google_analytics, if ga() function doesn't exist
      // it means that tracking shouldn't trigger at this place.
      if(typeof ga === 'undefined'){
        return;
      }

      // Grab all drupalSettings.
      var ga_settings = drupalSettings.google_analytics_search_api_autocomplete;

      // Find autocomplete widget by search ID.
      var widget = $('input[data-search-api-autocomplete-search="' + ga_settings.search_api_search_id + '"]');

      // Using module configuration add event listeners to autocomplete widget.
      $.each(ga_settings.ga_events, function(index, ui_event) {
        // once(), to avoid bubbling on AJAX callbacks.
        $(widget).once(ui_event).on(ui_event, function (event, ui) {
          // Depending on event, we pick up value from different place,
          // it can be a value of autocomplete widget, or an UI item.
          var eventLabel = false;

          switch(ui_event) {
            case 'autocompletesearch':
            case 'autocompleteresponse':
            case 'autocompleteopen':
            case 'autocompletechange':
            case 'autocompleteclose':
              eventLabel = $(event.target).val();
              break;
            case 'autocompleteselect':
            case 'autocompletefocus':
              eventLabel = ui.item.value;
              break;
          }

          // ga('send', 'event', [eventCategory], [eventAction], [eventLabel], [eventValue], [fieldsObject]);
          if (eventLabel) {
            ga( ga_settings.tracker_id + '.send', 'event', ga_settings.search_api_search_id, ui_event, eventLabel);
          }
        });
      });
    }
  };
})(jQuery, Drupal);